==> atlantic-2.0.1-sources.jar: org/mule/commons/atlantic/lambda/consumer/PentaConsumer.java <==
package org.mule.commons.atlantic.lambda.consumer;

import org.mule.commons.atlantic.lambda.function.PentaFunction;

/**
 * Represents an operation that accepts five input arguments and returns no result.  This is the five-arity
 * specialization of {@link Consumer}.
 * Unlike most other functional interfaces, {@code PentaConsumer} is expected to operate via side-effects.
 *
 * This is a functional interface whose functional method is {@link #accept(Object, Object, Object, Object, Object)}.
 *
 * @param <A> The type of the first argument to the operation.
 * @param <B> The type of the second argument to the operation.
 * @param <C> The type of the third argument to the operation.
 * @param <D> The type of the fourth argument to the operation.
 * @param <E> The type of the fifth argument to the operation.
 */
@FunctionalInterface
public interface PentaConsumer<A, B, C, D, E> extends AtlanticConsumer<PentaFunction<A, B, C, D, E, Void>> {

    /**
     * Performs this operation on the given arguments.
     *
     * @param a The first input argument.
     * @param b The second input argument.
     * @param c The third input argument.
     * @param d The fourth input argument.
     * @param e The fifth input argument.
     * @throws Throwable Any exception that the operation will throw.
     */
    void accept(A a, B b, C c, D d, E e) throws Throwable;

    @Override
    default PentaFunction<A, B, C, D, E, Void> toFunction() {
        return (a, b, c, d, e) -> {
            accept(a, b, c, d, e);
            return null;
        };
    }

}

==> atlantic-3.0.0-sources.jar: org/mule/commons/atlantic/lambda/consumer/PentaConsumer.java <==
package org.mule.commons.atlantic.lambda.consumer;

import org.mule.commons.atlantic.lambda.function.PentaFunction;
import org.mule.commons.atlantic.lambda.supplier.Supplier;

/**
 * Represents an operation that accepts five input arguments and returns no result.  This is the five-arity
 * specialization of {@link Consumer}.
 * Unlike most other functional interfaces, {@code PentaConsumer} is expected to operate via side-effects.
 *
 * This is a functional interface whose functional method is {@link #accept(Object, Object, Object, Object, Object)}.
 *
 * @param <A> The type of the first argument to the operation.
 * @param <B> The type of the second argument to the operation.
 * @param <C> The type of the third argument to the operation.
 * @param <D> The type of the fourth argument to the operation.
 * @param <E> The type of the fifth argument to the operation.
 */
@FunctionalInterface
public interface PentaConsumer<A, B, C, D, E> extends AtlanticConsumer<A, TetraConsumer<B, C, D, E>, PentaFunction<A, B, C, D, E, Void>> {

    @Override
    default TetraConsumer<B, C, D, E> downgrade(Supplier<A> supplier) {
        return (b, c, d, e) -> accept(supplier.get(), b, c, d, e);
    }

    /**
     * Performs this operation on the given arguments.
     *
     * @param a The first input argument.
     * @param b The second input argument.
     * @param c The third input argument.
     * @param d The fourth input argument.
     * @param e The fifth input argument.
     * @throws Throwable Any exception that the operation will throw.
     */
    void accept(A a, B b, C c, D d, E e) throws Throwable;

    @Override
    default PentaFunction<A, B, C, D, E, Void> toFunction() {
        return (a, b, c, d, e) -> {
            accept(a, b, c, d, e);
            return null;
        };
    }

}
